@@ -10,5 +10,5 @@ https://docs.djangoproject.com/en/1.8/howto/deployment/wsgi/
 import os
 os.environ.setdefault("DJANGO_SETTINGS_MODULE", "myproject.settings")
 
-from django.core.wsgi import get_wsgi_application  # flake8: noqa
+from django.core.wsgi import get_wsgi_application  # noqa
 application = get_wsgi_application()
