@@ -6,7 +6,7 @@ import time
 
 from django.conf import settings
 from django.db import models
-from django.utils.encoding import python_2_unicode_compatible
+from six import python_2_unicode_compatible
 
 from tastypie.utils import now
 
