@@ -28,7 +28,7 @@ def determine_format(request, serializer, default_format='application/json'):
             return serializer.get_mime_for_format(format)
 
     # If callback parameter is present, use JSONP.
-    if 'callback' in request.GET:
+    if 'callback' in request.GET and 'jsonp' in serializer.formats:
         return serializer.get_mime_for_format('jsonp')
 
     # Try to fallback on the Accepts header.
