@@ -1,7 +1,8 @@
 from __future__ import unicode_literals
 
 from django.conf import settings
-from django.utils import six
+
+import six
 
 
 _trailing_slash = '/?' if getattr(settings, 'TASTYPIE_ALLOW_MISSING_SLASH', False) else '/'
