@@ -3,8 +3,8 @@ import time
 
 from django.core.cache import cache
 from django.test import TestCase
-from django.utils.encoding import force_text
 
+from tastypie.compat import force_str
 from tastypie.models import ApiAccess
 from tastypie.throttle import BaseThrottle, CacheThrottle, CacheDBThrottle
 
@@ -140,8 +140,18 @@ class CacheDBThrottleTestCase(TestCase):
         self.assertEqual(ApiAccess.objects.count(), 7)
         self.assertEqual(ApiAccess.objects.filter(identifier='daniel').count(), 4)
 
+    def test_long_url(self, mocked_time):
+        # This test does nothing on SQLite - max length of a varchar is not enforced
+        # The test is here as an example, or for a future where we run tests on
+        # another database engine.
+        url = 'https://testserver/api/resource?' + 'longurlparams' * 100
+        throttle_1 = CacheDBThrottle(throttle_at=2, timeframe=5, expiration=2)
+        throttle_1.accessed(identifier='accessor', url=url)
+        access = ApiAccess.objects.filter(identifier='accessor').first()
+        self.assertEqual(access.url, url)
+
 
 class ModelTestCase(TestCase):
     def test_unicode(self):
         access = ApiAccess(identifier="testing", accessed=0)
-        self.assertEqual(force_text(access), 'testing @ 0')
+        self.assertEqual(force_str(access), 'testing @ 0')
