@@ -1,11 +1,18 @@
+from django.conf import settings
 from django.contrib.auth.models import User
 from django.contrib.gis.db import models
 
 from tastypie.utils import now
 
+if settings.DJANGO_VERSION >= settings.DJANGO_20:
+    GeoManager = models.Manager
+else:
+    GeoManager = models.GeoManager
+
 
 class GeoNote(models.Model):
-    user = models.ForeignKey(User, related_name='notes')
+    user = models.ForeignKey(User, related_name='notes',
+                             on_delete=models.CASCADE)
     title = models.CharField(max_length=255)
     slug = models.SlugField()
     content = models.TextField()
@@ -17,7 +24,7 @@ class GeoNote(models.Model):
     lines = models.MultiLineStringField(null=True, blank=True)
     polys = models.MultiPolygonField(null=True, blank=True)
 
-    objects = models.GeoManager()
+    objects = GeoManager()
 
     def __unicode__(self):
         return self.title
@@ -28,7 +35,8 @@ class GeoNote(models.Model):
 
 
 class AnnotatedGeoNote(models.Model):
-    note = models.OneToOneField(GeoNote, related_name='annotated', null=True)
+    note = models.OneToOneField(GeoNote, related_name='annotated', null=True,
+                                on_delete=models.CASCADE)
     annotations = models.TextField()
 
     def __unicode__(self):
