@@ -1,20 +1,23 @@
 import json
 
+from django.test.utils import override_settings
+from tastypie.exceptions import NotFound
+
 from basic.models import Note
 from testcases import TestCaseWithFixture
+from django.test.testcases import SimpleTestCase
 
 
+@override_settings(ROOT_URLCONF='validation.api.urls')
 class FilteringErrorsTestCase(TestCaseWithFixture):
-    urls = 'validation.api.urls'
-
     def test_valid_date(self):
         resp = self.client.get('/api/v1/notes/', data={
             'format': 'json',
-            'created__gte': '2010-03-31'
+            'created__gte': '2010-03-31 00:00:00Z'
         })
         self.assertEqual(resp.status_code, 200)
         deserialized = json.loads(resp.content.decode('utf-8'))
-        self.assertEqual(len(deserialized['objects']), Note.objects.filter(created__gte='2010-03-31').count())
+        self.assertEqual(len(deserialized['objects']), Note.objects.filter(created__gte='2010-03-31 00:00:00Z').count())
 
     def test_invalid_date(self):
         resp = self.client.get('/api/v1/notes/', data={
@@ -24,9 +27,42 @@ class FilteringErrorsTestCase(TestCaseWithFixture):
         self.assertEqual(resp.status_code, 400)
 
 
-class PostNestResouceValidationTestCase(TestCaseWithFixture):
-    urls = 'validation.api.urls'
+@override_settings(ROOT_URLCONF='validation.api.urls')
+class PostRelatedUrlValidationTestCase(TestCaseWithFixture):
+    def test_valid_url(self):
+        data_with_pk = json.dumps({
+            'title': 'Test title related pk',
+            'slug': 'test-slug-related-pk',
+            'content': 'This is the content',
+            'user': {'pk': 1},
+        })
+        data_with_url = json.dumps({
+            'title': 'Test title related url',
+            'slug': 'test-slug-related-url',
+            'content': 'This is the content',
+            'user': '/api/v1/users/1/',
+        })
+        resp_with_pk = self.client.post('/api/v1/notes/', data=data_with_pk, content_type='application/json')
+        self.assertEqual(resp_with_pk.status_code, 201)
+        note_posted_with_pk = json.loads(self.client.get(resp_with_pk['location']).content.decode('utf-8'))
+        resp_with_url = self.client.post('/api/v1/notes/', data=data_with_url, content_type='application/json')
+        self.assertEqual(resp_with_url.status_code, 201)
+        note_posted_with_url = json.loads(self.client.get(resp_with_url['location']).content.decode('utf-8'))
+        self.assertEqual(note_posted_with_pk['user'], note_posted_with_url['user'])
 
+    def test_invalid_url(self):
+        data = json.dumps({
+            'title': 'Test title related url',
+            'slug': 'test-slug-related-url',
+            'content': 'This is the content',
+            'user': 'invalid-url',
+        })
+        with self.assertRaises(NotFound):
+            self.client.post('/api/v1/notes/', data=data, content_type='application/json')
+
+
+@override_settings(ROOT_URLCONF='validation.api.urls')
+class PostNestResouceValidationTestCase(TestCaseWithFixture):
     def test_valid_data(self):
         data = json.dumps({
             'title': 'Test Title',
@@ -62,9 +98,8 @@ class PostNestResouceValidationTestCase(TestCaseWithFixture):
         })
 
 
+@override_settings(ROOT_URLCONF='validation.api.urls')
 class PutDetailNestResouceValidationTestCase(TestCaseWithFixture):
-    urls = 'validation.api.urls'
-
     def test_valid_data(self):
         data = json.dumps({
             'title': 'Test Title',
@@ -100,9 +135,8 @@ class PutDetailNestResouceValidationTestCase(TestCaseWithFixture):
         })
 
 
+@override_settings(ROOT_URLCONF='validation.api.urls')
 class PutListNestResouceValidationTestCase(TestCaseWithFixture):
-    urls = 'validation.api.urls'
-
     def test_valid_data(self):
         data = json.dumps({'objects': [
             {
@@ -158,3 +192,13 @@ class PutListNestResouceValidationTestCase(TestCaseWithFixture):
                 'annotations': ['This field is required.']
             }
         })
+
+
+class TestJSONPValidation(SimpleTestCase):
+    """
+    Explicitly run the doctests for tastypie.utils.validate_jsonp
+    """
+    def test_jsonp(self):
+        import tastypie.utils.validate_jsonp
+        import doctest
+        doctest.testmod(tastypie.utils.validate_jsonp)
